@@ -124,6 +124,11 @@ test_that("custom indent is used", {
   expect_equal("foo:\n   bar:\n   - foo\n   - bar\n", result)
 })
 
+test_that("block sequences in mapping context are indented when indent.mapping.sequence is TRUE", {
+  result <- as.yaml(list(foo=list(bar=list('foo', 'bar'))), indent.mapping.sequence = TRUE)
+  expect_equal("foo:\n  bar:\n    - foo\n    - bar\n", result)
+})
+
 test_that("indent value is validated", {
   expect_that(as.yaml(list(foo=list(bar=list('foo', 'bar'))), indent = 0),
     throws_error())
@@ -218,3 +223,9 @@ test_that("precision must be in the range 1..22", {
   expect_that(as.yaml(12345, precision = 23),
     throws_error())
 })
+
+test_that("factor with NAs is emitted properly", {
+  x <- factor('foo', levels=c('bar', 'baz'))
+  result <- as.yaml(x)
+  expect_equal(".na.character\n...\n", result, expected.label = result)
+})
